import React, { useRef } from 'react';
import { Button } from '../buttons';
import { ArrowBack, ArrowForward } from '@mui/icons-material';

export type PaginationProps = {
  currentPage: number;
  totalPages: number;
  onPageChange: (page: number) => void;
  itemsPerPageInput: number;
  numItemsArrayReal: number;
  totalItems: number;
};

export const Pagination: React.FC<PaginationProps> = ({
  currentPage,
  totalPages,
  onPageChange,
  itemsPerPageInput,
  numItemsArrayReal,
  totalItems,
}) => {
  const pageNumbers = Array.from({ length: totalPages }, (_, index) => index + 1);

  const firstItem = (currentPage - 1) * itemsPerPageInput + 1;
  const lastItem = Math.min(currentPage * itemsPerPageInput, totalPages);

  const goToPreviousPage = () => {
    if (currentPage > 1) {
      onPageChange(currentPage - 1);
    }
  };

  const goToNextPage = () => {
    if (currentPage < totalPages) {
      onPageChange(currentPage + 1);
    }
  };

  return (
    <div className="table-pagination flex flex-col items-center py-2 gap-1.5">
      <div className="inline-block text-sm">
        <span className="font-semibold">{`${firstItem} - ${numItemsArrayReal}`}</span> of {totalItems}
      </div>
      <div className="grid grid-cols-2 gap-2">
        <Button
          size={'sm'}
          label="Previous"
          variant="outline"
          iconComponent={<ArrowBack />}
          onClick={goToPreviousPage}
          disabled={currentPage === 1}
        />
        <Button
          size={'sm'}
          label="Next"
          variant="outline"
          iconComponent={<ArrowForward />}
          iconPosition="trailing"
          onClick={goToNextPage}
          disabled={currentPage === totalPages}
        />
      </div>
    </div>
  );
};

export default Pagination;
