import React from 'react';
import { Add, FitScreenOutlined, HighlightAltOutlined, Remove, SearchOutlined } from '@mui/icons-material';
import { FlyToInterpolator } from 'deck.gl/typed';
import { getLocationInfo } from '../utlis';

type Props = {
  mapSize: boolean;
  setMapSize: React.Dispatch<React.SetStateAction<boolean>>;
  setViewport: any;
  flyToBoundingBox: any;
  selectingRectangle: boolean;
  setSelectingRectangle: React.Dispatch<React.SetStateAction<boolean>>;
};

export default function SecondaryMenu({
  mapSize,
  setMapSize,
  setViewport,
  flyToBoundingBox,
  setSelectingRectangle,
  selectingRectangle,
}: Props) {
  const [searchOpen, setSearchOpen] = React.useState<boolean>(false);
  const [search, setSearch] = React.useState<string>('');

  const handleSearch = async (e: { key: string }) => {
    if (e.key !== 'Enter') return;
    try {
      const boundingbox = await getLocationInfo(search);
      if (!boundingbox) throw new Error('No data found');
      const [minLat, maxLat, minLon, maxLon] = boundingbox;
      flyToBoundingBox(minLat, maxLat, minLon, maxLon);
      setSearchOpen(false);
      setSearch('');
    } catch (error) {
      console.log(error);
    }
  };

  return (
    <div className="absolute z-10 top-2.5 left-2.5 flex flex-col justify-center items-start">
      <div
        title="Full screen"
        onClick={() => setMapSize(!mapSize)}
        className="bg-light p-1 mb-1 cursor-pointer shadow-sm flex justify-center items-center hover:bg-secondary"
      >
        <FitScreenOutlined />
      </div>
      <div
        className="bg-light p-1 mb-1 cursor-pointer shadow-sm flex justify-center items-center hover:bg-secondary"
        title="Search for location"
      >
        <SearchOutlined onClick={() => setSearchOpen(!searchOpen)} />
        {searchOpen && (
          <div className="flex">
            <input value={search} onChange={(e) => setSearch(e.target.value)} onKeyDown={handleSearch} />
          </div>
        )}
      </div>
      <div
        className="bg-light p-1 mb-1 cursor-pointer shadow-sm flex justify-center items-center hover:bg-secondary"
        title="Select objects in an area"
      >
        <HighlightAltOutlined onClick={() => setSelectingRectangle(!selectingRectangle)} />
      </div>
      <div
        title="Zoom in"
        onClick={() =>
          setViewport((prevViewport: { zoom: number }) => ({
            ...prevViewport,
            zoom: prevViewport.zoom + 1,
            transitionDuration: 100,
            transitionInterpolator: new FlyToInterpolator(),
          }))
        }
        className="bg-light p-1 mb-1 cursor-pointer shadow-sm flex justify-center items-center hover:bg-secondary"
      >
        <Add />
      </div>
      <div
        title="Zoom out"
        onClick={() =>
          setViewport((prevViewport: { zoom: number }) => ({
            ...prevViewport,
            zoom: prevViewport.zoom - 1,
            transitionDuration: 100,
            transitionInterpolator: new FlyToInterpolator(),
          }))
        }
        className="bg-light p-1 mb-1 cursor-pointer shadow-sm flex justify-center items-center hover:bg-secondary"
      >
        <Remove />
      </div>
    </div>
  );
}
